-- the tex table has overlap

return {
 ["aleph"]={
  "AlephVersion",
  "Alephminorversion",
  "Alephrevision",
  "Alephversion",
  "Omegaminorversion",
  "Omegarevision",
  "Omegaversion",
  "boxdir",
  "pagebottomoffset",
  "pagerightoffset",
 },
 ["etex"]={
  "botmarks",
  "clubpenalties",
  "currentgrouplevel",
  "currentgrouptype",
  "currentifbranch",
  "currentiflevel",
  "currentiftype",
  "detokenize",
  "dimexpr",
  "displaywidowpenalties",
  "eTeXVersion",
  "eTeXminorversion",
  "eTeXrevision",
  "eTeXversion",
  "everyeof",
  "firstmarks",
  "fontchardp",
  "fontcharht",
  "fontcharic",
  "fontcharwd",
  "glueexpr",
  "glueshrink",
  "glueshrinkorder",
  "gluestretch",
  "gluestretchorder",
  "gluetomu",
  "ifcsname",
  "ifdefined",
  "iffontchar",
  "interactionmode",
  "interlinepenalties",
  "lastlinefit",
  "lastnodetype",
  "marks",
  "muexpr",
  "mutoglue",
  "numexpr",
  "pagediscards",
  "parshapedimen",
  "parshapeindent",
  "parshapelength",
  "predisplaydirection",
  "protected",
  "readline",
  "savinghyphcodes",
  "savingvdiscards",
  "scantokens",
  "showgroups",
  "showifs",
  "showtokens",
  "splitbotmarks",
  "splitdiscards",
  "splitfirstmarks",
  "topmarks",
  "tracingassigns",
  "tracinggroups",
  "tracingifs",
  "tracingnesting",
  "tracingscantokens",
  "unexpanded",
  "unless",
  "widowpenalties",
 },
 ["luatex"]={
  "Uchar",
  "Udelcode",
  "Udelcodenum",
  "Udelimiter",
  "Udelimiterover",
  "Udelimiterunder",
  "Umathaccent",
--"Umathaccents",
  "Umathaxis",
  "Umathbinbinspacing",
  "Umathbinclosespacing",
  "Umathbininnerspacing",
  "Umathbinopenspacing",
  "Umathbinopspacing",
  "Umathbinordspacing",
  "Umathbinpunctspacing",
  "Umathbinrelspacing",
--"Umathbotaccent",
  "Umathchar",
  "Umathchardef",
  "Umathcharnum",
  "Umathclosebinspacing",
  "Umathcloseclosespacing",
  "Umathcloseinnerspacing",
  "Umathcloseopenspacing",
  "Umathcloseopspacing",
  "Umathcloseordspacing",
  "Umathclosepunctspacing",
  "Umathcloserelspacing",
  "Umathcode",
  "Umathcodenum",
  "Umathconnectoroverlapmin",
  "Umathfractiondelsize",
  "Umathfractiondenomdown",
  "Umathfractiondenomvgap",
  "Umathfractionnumup",
  "Umathfractionnumvgap",
  "Umathfractionrule",
  "Umathinnerbinspacing",
  "Umathinnerclosespacing",
  "Umathinnerinnerspacing",
  "Umathinneropenspacing",
  "Umathinneropspacing",
  "Umathinnerordspacing",
  "Umathinnerpunctspacing",
  "Umathinnerrelspacing",
  "Umathlimitabovebgap",
  "Umathlimitabovekern",
  "Umathlimitabovevgap",
  "Umathlimitbelowbgap",
  "Umathlimitbelowkern",
  "Umathlimitbelowvgap",
  "Umathopbinspacing",
  "Umathopclosespacing",
  "Umathopenbinspacing",
  "Umathopenclosespacing",
  "Umathopeninnerspacing",
  "Umathopenopenspacing",
  "Umathopenopspacing",
  "Umathopenordspacing",
  "Umathopenpunctspacing",
  "Umathopenrelspacing",
  "Umathoperatorsize",
  "Umathopinnerspacing",
  "Umathopopenspacing",
  "Umathopopspacing",
  "Umathopordspacing",
  "Umathoppunctspacing",
  "Umathoprelspacing",
  "Umathordbinspacing",
  "Umathordclosespacing",
  "Umathordinnerspacing",
  "Umathordopenspacing",
  "Umathordopspacing",
  "Umathordordspacing",
  "Umathordpunctspacing",
  "Umathordrelspacing",
  "Umathoverbarkern",
  "Umathoverbarrule",
  "Umathoverbarvgap",
  "Umathoverdelimiterbgap",
  "Umathoverdelimitervgap",
  "Umathpunctbinspacing",
  "Umathpunctclosespacing",
  "Umathpunctinnerspacing",
  "Umathpunctopenspacing",
  "Umathpunctopspacing",
  "Umathpunctordspacing",
  "Umathpunctpunctspacing",
  "Umathpunctrelspacing",
  "Umathquad",
  "Umathradicaldegreeafter",
  "Umathradicaldegreebefore",
  "Umathradicaldegreeraise",
  "Umathradicalkern",
  "Umathradicalrule",
  "Umathradicalvgap",
  "Umathrelbinspacing",
  "Umathrelclosespacing",
  "Umathrelinnerspacing",
  "Umathrelopenspacing",
  "Umathrelopspacing",
  "Umathrelordspacing",
  "Umathrelpunctspacing",
  "Umathrelrelspacing",
  "Umathspaceafterscript",
  "Umathstackdenomdown",
  "Umathstacknumup",
  "Umathstackvgap",
  "Umathsubshiftdown",
  "Umathsubshiftdrop",
  "Umathsubsupshiftdown",
  "Umathsubsupvgap",
  "Umathsubtopmax",
  "Umathsupbottommin",
  "Umathsupshiftdrop",
  "Umathsupshiftup",
  "Umathsupsubbottommax",
  "Umathunderbarkern",
  "Umathunderbarrule",
  "Umathunderbarvgap",
  "Umathunderdelimiterbgap",
  "Umathunderdelimitervgap",
  "Uoverdelimiter",
  "Uradical",
  "Uroot",
  "Ustack",
  "Ustartdisplaymath",
  "Ustartmath",
  "Ustopdisplaymath",
  "Ustopmath",
  "Usubscript",
  "Usuperscript",
  "Uunderdelimiter",
  "alignmark",
  "aligntab",
  "attribute",
  "attributedef",
  "catcodetable",
  "clearmarks",
  "crampeddisplaystyle",
  "crampedscriptscriptstyle",
  "crampedscriptstyle",
  "crampedtextstyle",
  "fontid",
  "formatname",
  "gleaders",
  "ifabsdim",
  "ifabsnum",
  "ifprimitive",
  "initcatcodetable",
  "latelua",
  "luaescapestring",
  "luastartup",
  "luatexdatestamp",
  "luatexrevision",
  "luatexversion",
  "luafunction",
  "mathstyle",
  "nokerns",
  "noligs",
  "outputbox",
  "pageleftoffset",
  "pagetopoffset",
  "postexhyphenchar",
  "posthyphenchar",
  "preexhyphenchar",
  "prehyphenchar",
  "primitive",
  "savecatcodetable",
  "scantextokens",
  "suppressfontnotfounderror",
  "suppressifcsnameerror",
  "suppresslongerror",
  "suppressoutererror",
  "synctex",
 },
 ["omega"]={
  "OmegaVersion",
  "bodydir",
  "chardp",
  "charht",
  "charit",
  "charwd",
  "leftghost",
  "localbrokenpenalty",
  "localinterlinepenalty",
  "localleftbox",
  "localrightbox",
  "mathdir",
  "odelcode",
  "odelimiter",
  "omathaccent",
  "omathchar",
  "omathchardef",
  "omathcode",
  "oradical",
  "pagedir",
  "pageheight",
  "pagewidth",
  "pardir",
  "rightghost",
  "textdir",
 },
 ["pdftex"]={
  "efcode",
  "expanded",
  "ifincsname",
  "ifpdfabsdim",
  "ifpdfabsnum",
  "ifpdfprimitive",
  "leftmarginkern",
  "letterspacefont",
  "lpcode",
  "pdfadjustspacing",
  "pdfannot",
  "pdfcatalog",
  "pdfcolorstack",
  "pdfcolorstackinit",
  "pdfcompresslevel",
  "pdfcopyfont",
  "pdfcreationdate",
  "pdfdecimaldigits",
  "pdfdest",
  "pdfdestmargin",
  "pdfdraftmode",
  "pdfeachlinedepth",
  "pdfeachlineheight",
  "pdfendlink",
  "pdfendthread",
  "pdffirstlineheight",
  "pdffontattr",
  "pdffontexpand",
  "pdffontname",
  "pdffontobjnum",
  "pdffontsize",
  "pdfgamma",
  "pdfgentounicode",
  "pdfglyphtounicode",
  "pdfhorigin",
  "pdfignoreddimen",
  "pdfimageapplygamma",
  "pdfimagegamma",
  "pdfimagehicolor",
  "pdfimageresolution",
  "pdfincludechars",
  "pdfinclusioncopyfonts",
  "pdfinclusionerrorlevel",
  "pdfinfo",
  "pdfinsertht",
  "pdflastannot",
  "pdflastlinedepth",
  "pdflastlink",
  "pdflastobj",
  "pdflastxform",
  "pdflastximage",
  "pdflastximagecolordepth",
  "pdflastximagepages",
  "pdflastxpos",
  "pdflastypos",
  "pdflinkmargin",
  "pdfliteral",
  "pdfmapfile",
  "pdfmapline",
  "pdfminorversion",
  "pdfnames",
  "pdfnoligatures",
  "pdfnormaldeviate",
  "pdfobj",
  "pdfobjcompresslevel",
  "pdfoptionpdfminorversion",
  "pdfoutline",
  "pdfoutput",
  "pdfpageattr",
  "pdfpagebox",
  "pdfpageheight",
  "pdfpageref",
  "pdfpageresources",
  "pdfpagesattr",
  "pdfpagewidth",
  "pdfpkmode",
  "pdfpkresolution",
  "pdfprimitive",
  "pdfprotrudechars",
  "pdfpxdimen",
  "pdfrandomseed",
  "pdfrefobj",
  "pdfrefxform",
  "pdfrefximage",
  "pdfreplacefont",
  "pdfrestore",
  "pdfretval",
  "pdfsave",
  "pdfsavepos",
  "pdfsetmatrix",
  "pdfsetrandomseed",
  "pdfstartlink",
  "pdfstartthread",
  "pdftexbanner",
  "pdftexrevision",
  "pdftexversion",
  "pdfthread",
  "pdfthreadmargin",
  "pdftracingfonts",
  "pdftrailer",
  "pdfuniformdeviate",
  "pdfuniqueresname",
  "pdfvorigin",
  "pdfxform",
  "pdfxformattr",
  "pdfxformname",
  "pdfxformresources",
  "pdfximage",
  "pdfximagebbox",
  "quitvmode",
  "rightmarginkern",
  "rpcode",
  "tagcode",
 },
 ["tex"]={
  "-",
  "/",
  "AlephVersion",
  "Alephminorversion",
  "Alephrevision",
  "Alephversion",
  "OmegaVersion",
  "Omegaminorversion",
  "Omegarevision",
  "Omegaversion",
  "Udelcode",
  "Udelcodenum",
  "Udelimiter",
  "Udelimiterover",
  "Udelimiterunder",
  "Umathaccent",
--"Umathaccents",
  "Umathaxis",
  "Umathbinbinspacing",
  "Umathbinclosespacing",
  "Umathbininnerspacing",
  "Umathbinopenspacing",
  "Umathbinopspacing",
  "Umathbinordspacing",
  "Umathbinpunctspacing",
  "Umathbinrelspacing",
--"Umathbotaccent",
  "Umathchar",
  "Umathchardef",
  "Umathcharnum",
  "Umathclosebinspacing",
  "Umathcloseclosespacing",
  "Umathcloseinnerspacing",
  "Umathcloseopenspacing",
  "Umathcloseopspacing",
  "Umathcloseordspacing",
  "Umathclosepunctspacing",
  "Umathcloserelspacing",
  "Umathcode",
  "Umathcodenum",
  "Umathconnectoroverlapmin",
  "Umathfractiondelsize",
  "Umathfractiondenomdown",
  "Umathfractiondenomvgap",
  "Umathfractionnumup",
  "Umathfractionnumvgap",
  "Umathfractionrule",
  "Umathinnerbinspacing",
  "Umathinnerclosespacing",
  "Umathinnerinnerspacing",
  "Umathinneropenspacing",
  "Umathinneropspacing",
  "Umathinnerordspacing",
  "Umathinnerpunctspacing",
  "Umathinnerrelspacing",
  "Umathlimitabovebgap",
  "Umathlimitabovekern",
  "Umathlimitabovevgap",
  "Umathlimitbelowbgap",
  "Umathlimitbelowkern",
  "Umathlimitbelowvgap",
  "Umathopbinspacing",
  "Umathopclosespacing",
  "Umathopenbinspacing",
  "Umathopenclosespacing",
  "Umathopeninnerspacing",
  "Umathopenopenspacing",
  "Umathopenopspacing",
  "Umathopenordspacing",
  "Umathopenpunctspacing",
  "Umathopenrelspacing",
  "Umathoperatorsize",
  "Umathopinnerspacing",
  "Umathopopenspacing",
  "Umathopopspacing",
  "Umathopordspacing",
  "Umathoppunctspacing",
  "Umathoprelspacing",
  "Umathordbinspacing",
  "Umathordclosespacing",
  "Umathordinnerspacing",
  "Umathordopenspacing",
  "Umathordopspacing",
  "Umathordordspacing",
  "Umathordpunctspacing",
  "Umathordrelspacing",
  "Umathoverbarkern",
  "Umathoverbarrule",
  "Umathoverbarvgap",
  "Umathoverdelimiterbgap",
  "Umathoverdelimitervgap",
  "Umathpunctbinspacing",
  "Umathpunctclosespacing",
  "Umathpunctinnerspacing",
  "Umathpunctopenspacing",
  "Umathpunctopspacing",
  "Umathpunctordspacing",
  "Umathpunctpunctspacing",
  "Umathpunctrelspacing",
  "Umathquad",
  "Umathradicaldegreeafter",
  "Umathradicaldegreebefore",
  "Umathradicaldegreeraise",
  "Umathradicalkern",
  "Umathradicalrule",
  "Umathradicalvgap",
  "Umathrelbinspacing",
  "Umathrelclosespacing",
  "Umathrelinnerspacing",
  "Umathrelopenspacing",
  "Umathrelopspacing",
  "Umathrelordspacing",
  "Umathrelpunctspacing",
  "Umathrelrelspacing",
  "Umathspaceafterscript",
  "Umathstackdenomdown",
  "Umathstacknumup",
  "Umathstackvgap",
  "Umathsubshiftdown",
  "Umathsubshiftdrop",
  "Umathsubsupshiftdown",
  "Umathsubsupvgap",
  "Umathsubtopmax",
  "Umathsupbottommin",
  "Umathsupshiftdrop",
  "Umathsupshiftup",
  "Umathsupsubbottommax",
  "Umathunderbarkern",
  "Umathunderbarrule",
  "Umathunderbarvgap",
  "Umathunderdelimiterbgap",
  "Umathunderdelimitervgap",
  "Uoverdelimiter",
  "Uradical",
  "Uroot",
  "Ustack",
  "Ustartdisplaymath",
  "Ustartmath",
  "Ustopdisplaymath",
  "Ustopmath",
  "Usubscript",
  "Usuperscript",
  "Uunderdelimiter",
  "above",
  "abovedisplayshortskip",
  "abovedisplayskip",
  "abovewithdelims",
  "accent",
  "adjdemerits",
  "advance",
  "afterassignment",
  "aftergroup",
  "alignmark",
  "aligntab",
  "atop",
  "atopwithdelims",
  "attribute",
  "attributedef",
  "badness",
  "baselineskip",
  "batchmode",
  "begingroup",
  "belowdisplayshortskip",
  "belowdisplayskip",
  "binoppenalty",
  "bodydir",
  "botmark",
  "botmarks",
  "box",
  "boxdir",
  "boxmaxdepth",
  "brokenpenalty",
  "catcode",
  "catcodetable",
  "char",
  "chardef",
--"chardp",
--"charht",
--"charit",
--"charwd",
  "cleaders",
  "clearmarks",
  "closein",
  "closeout",
  "clubpenalties",
  "clubpenalty",
  "copy",
  "count",
  "countdef",
  "cr",
  "crampeddisplaystyle",
  "crampedscriptscriptstyle",
  "crampedscriptstyle",
  "crampedtextstyle",
  "crcr",
  "csname",
  "currentgrouplevel",
  "currentgrouptype",
  "currentifbranch",
  "currentiflevel",
  "currentiftype",
  "day",
  "deadcycles",
  "def",
  "defaulthyphenchar",
  "defaultskewchar",
  "delcode",
  "delimiter",
  "delimiterfactor",
  "delimitershortfall",
  "detokenize",
  "dimen",
  "dimendef",
  "dimexpr",
  "directlua",
  "discretionary",
  "displayindent",
  "displaylimits",
  "displaystyle",
  "displaywidowpenalties",
  "displaywidowpenalty",
  "displaywidth",
  "divide",
  "doublehyphendemerits",
  "dp",
  "dump",
  "eTeXVersion",
  "eTeXminorversion",
  "eTeXrevision",
  "eTeXversion",
  "edef",
  "efcode",
  "else",
  "emergencystretch",
  "end",
  "endcsname",
  "endgroup",
  "endinput",
  "endlinechar",
  "eqno",
  "errhelp",
  "errmessage",
  "errorcontextlines",
  "errorstopmode",
  "escapechar",
  "everycr",
  "everydisplay",
  "everyeof",
  "everyhbox",
  "everyjob",
  "everymath",
  "everypar",
  "everyvbox",
  "exhyphenchar",
  "exhyphenpenalty",
  "expandafter",
  "expanded",
  "fam",
  "fi",
  "finalhyphendemerits",
  "firstmark",
  "firstmarks",
  "floatingpenalty",
  "font",
  "fontchardp",
  "fontcharht",
  "fontcharic",
  "fontcharwd",
  "fontdimen",
  "fontid",
  "fontname",
  "formatname",
  "futurelet",
  "gdef",
  "gleaders",
  "global",
  "globaldefs",
  "glueexpr",
  "glueshrink",
  "glueshrinkorder",
  "gluestretch",
  "gluestretchorder",
  "gluetomu",
  "halign",
  "hangafter",
  "hangindent",
  "hbadness",
  "hbox",
  "hfil",
  "hfill",
  "hfilneg",
  "hfuzz",
  "hoffset",
  "holdinginserts",
  "hrule",
  "hsize",
  "hskip",
  "hss",
  "ht",
  "hyphenation",
  "hyphenchar",
  "hyphenpenalty",
  "if",
  "ifabsdim",
  "ifabsnum",
  "ifcase",
  "ifcat",
  "ifcsname",
  "ifdefined",
  "ifdim",
  "ifeof",
  "iffalse",
  "iffontchar",
  "ifhbox",
  "ifhmode",
  "ifincsname",
  "ifinner",
  "ifmmode",
  "ifnum",
  "ifodd",
  "ifpdfabsdim",
  "ifpdfabsnum",
  "ifpdfprimitive",
  "ifprimitive",
  "iftrue",
  "ifvbox",
  "ifvmode",
  "ifvoid",
  "ifx",
  "ignorespaces",
  "immediate",
  "indent",
  "initcatcodetable",
  "input",
  "inputlineno",
  "insert",
  "insertpenalties",
  "interactionmode",
  "interlinepenalties",
  "interlinepenalty",
  "jobname",
  "kern",
  "language",
  "lastbox",
  "lastkern",
  "lastlinefit",
  "lastnodetype",
  "lastpenalty",
  "lastskip",
  "latelua",
  "lccode",
  "leaders",
  "left",
  "leftghost",
  "lefthyphenmin",
  "leftmarginkern",
  "leftskip",
  "leqno",
  "let",
  "letterspacefont",
  "limits",
  "linepenalty",
  "lineskip",
  "lineskiplimit",
  "localbrokenpenalty",
  "localinterlinepenalty",
  "localleftbox",
  "localrightbox",
  "long",
  "looseness",
  "lower",
  "lowercase",
  "lpcode",
  "luaescapestring",
  "luastartup",
  "luatexdatestamp",
  "luatexrevision",
  "luatexversion",
  "mag",
  "mark",
  "marks",
  "mathaccent",
  "mathbin",
  "mathchar",
  "mathchardef",
  "mathchoice",
  "mathclose",
  "mathcode",
  "mathdir",
  "mathinner",
  "mathop",
  "mathopen",
  "mathord",
  "mathpunct",
  "mathrel",
  "mathstyle",
  "mathsurround",
  "maxdeadcycles",
  "maxdepth",
  "meaning",
  "medmuskip",
  "message",
  "middle",
  "mkern",
  "month",
  "moveleft",
  "moveright",
  "mskip",
  "muexpr",
  "multiply",
  "muskip",
  "muskipdef",
  "mutoglue",
  "newlinechar",
  "noalign",
  "noboundary",
  "noexpand",
  "noindent",
  "nokerns",
  "noligs",
  "nolimits",
  "nolocaldirs",
  "nolocalwhatsits",
  "nonscript",
  "nonstopmode",
  "nulldelimiterspace",
  "nullfont",
  "number",
  "numexpr",
  "odelcode",
  "odelimiter",
  "omathaccent",
  "omathchar",
  "omathchardef",
  "omathcode",
  "omit",
  "openin",
  "openout",
  "or",
  "oradical",
  "outer",
  "output",
  "outputbox",
  "outputpenalty",
  "over",
  "overfullrule",
  "overline",
  "overwithdelims",
  "pagebottomoffset",
  "pagedepth",
  "pagedir",
  "pagediscards",
  "pagefilllstretch",
  "pagefillstretch",
  "pagefilstretch",
  "pagegoal",
  "pageheight",
  "pageleftoffset",
  "pagerightoffset",
  "pageshrink",
  "pagestretch",
  "pagetopoffset",
  "pagetotal",
  "pagewidth",
  "par",
  "pardir",
  "parfillskip",
  "parindent",
  "parshape",
  "parshapedimen",
  "parshapeindent",
  "parshapelength",
  "parskip",
  "patterns",
  "pausing",
  "pdfadjustspacing",
  "pdfannot",
  "pdfcatalog",
  "pdfcolorstack",
  "pdfcolorstackinit",
  "pdfcompresslevel",
  "pdfcopyfont",
  "pdfcreationdate",
  "pdfdecimaldigits",
  "pdfdest",
  "pdfdestmargin",
  "pdfdraftmode",
  "pdfeachlinedepth",
  "pdfeachlineheight",
  "pdfendlink",
  "pdfendthread",
  "pdffirstlineheight",
  "pdffontattr",
  "pdffontexpand",
  "pdffontname",
  "pdffontobjnum",
  "pdffontsize",
  "pdfgamma",
  "pdfgentounicode",
  "pdfglyphtounicode",
  "pdfhorigin",
  "pdfignoreddimen",
  "pdfimageapplygamma",
  "pdfimagegamma",
  "pdfimagehicolor",
  "pdfimageresolution",
  "pdfincludechars",
  "pdfinclusioncopyfonts",
  "pdfinclusionerrorlevel",
  "pdfinfo",
  "pdfinsertht",
  "pdflastannot",
  "pdflastlinedepth",
  "pdflastlink",
  "pdflastobj",
  "pdflastxform",
  "pdflastximage",
  "pdflastximagecolordepth",
  "pdflastximagepages",
  "pdflastxpos",
  "pdflastypos",
  "pdflinkmargin",
  "pdfliteral",
  "pdfmapfile",
  "pdfmapline",
  "pdfminorversion",
  "pdfnames",
  "pdfnoligatures",
  "pdfnormaldeviate",
  "pdfobj",
  "pdfobjcompresslevel",
  "pdfoptionpdfminorversion",
  "pdfoutline",
  "pdfoutput",
  "pdfpageattr",
  "pdfpagebox",
  "pdfpageheight",
  "pdfpageref",
  "pdfpageresources",
  "pdfpagesattr",
  "pdfpagewidth",
  "pdfpkmode",
  "pdfpkresolution",
  "pdfprimitive",
  "pdfprotrudechars",
  "pdfpxdimen",
  "pdfrandomseed",
  "pdfrefobj",
  "pdfrefxform",
  "pdfrefximage",
  "pdfreplacefont",
  "pdfrestore",
  "pdfretval",
  "pdfsave",
  "pdfsavepos",
  "pdfsetmatrix",
  "pdfsetrandomseed",
  "pdfstartlink",
  "pdfstartthread",
  "pdftexbanner",
  "pdftexrevision",
  "pdftexversion",
  "pdfthread",
  "pdfthreadmargin",
  "pdftracingfonts",
  "pdftrailer",
  "pdfuniformdeviate",
  "pdfuniqueresname",
  "pdfvorigin",
  "pdfxform",
  "pdfxformattr",
  "pdfxformname",
  "pdfxformresources",
  "pdfximage",
  "pdfximagebbox",
  "penalty",
  "postdisplaypenalty",
  "postexhyphenchar",
  "posthyphenchar",
  "predisplaydirection",
  "predisplaypenalty",
  "predisplaysize",
  "preexhyphenchar",
  "prehyphenchar",
  "pretolerance",
  "prevdepth",
  "prevgraf",
  "primitive",
  "protected",
  "quitvmode",
  "radical",
  "raise",
  "read",
  "readline",
  "relax",
  "relpenalty",
  "right",
  "rightghost",
  "righthyphenmin",
  "rightmarginkern",
  "rightskip",
  "romannumeral",
  "rpcode",
  "savecatcodetable",
  "savinghyphcodes",
  "savingvdiscards",
  "scantextokens",
  "scantokens",
  "scriptfont",
  "scriptscriptfont",
  "scriptscriptstyle",
  "scriptspace",
  "scriptstyle",
  "scrollmode",
  "setbox",
  "setlanguage",
  "sfcode",
  "shipout",
  "show",
  "showbox",
  "showboxbreadth",
  "showboxdepth",
  "showgroups",
  "showifs",
  "showlists",
  "showthe",
  "showtokens",
  "skewchar",
  "skip",
  "skipdef",
--"skipexpr",
  "spacefactor",
  "spaceskip",
  "span",
  "special",
  "splitbotmark",
  "splitbotmarks",
  "splitdiscards",
  "splitfirstmark",
  "splitfirstmarks",
  "splitmaxdepth",
  "splittopskip",
  "string",
  "suppressfontnotfounderror",
  "suppressifcsnameerror",
  "suppresslongerror",
  "suppressoutererror",
  "synctex",
  "tabskip",
  "tagcode",
  "textdir",
  "textfont",
  "textstyle",
  "the",
  "thickmuskip",
  "thinmuskip",
  "time",
  "toks",
  "toksdef",
  "tolerance",
  "topmark",
  "topmarks",
  "topskip",
  "tracingassigns",
  "tracingcommands",
  "tracinggroups",
  "tracingifs",
  "tracinglostchars",
  "tracingmacros",
  "tracingnesting",
  "tracingonline",
  "tracingoutput",
  "tracingpages",
  "tracingparagraphs",
  "tracingrestores",
  "tracingscantokens",
  "tracingstats",
  "uccode",
  "uchyph",
  "underline",
  "unexpanded",
  "unhbox",
  "unhcopy",
  "unkern",
  "unless",
  "unpenalty",
  "unskip",
  "unvbox",
  "unvcopy",
  "uppercase",
  "vadjust",
  "valign",
  "vbadness",
  "vbox",
  "vcenter",
  "vfil",
  "vfill",
  "vfilneg",
  "vfuzz",
  "voffset",
  "vrule",
  "vsize",
  "vskip",
  "vsplit",
  "vss",
  "vtop",
  "wd",
  "widowpenalties",
  "widowpenalty",
  "write",
  "xdef",
  "xleaders",
  "xspaceskip",
  "year",
 },
 ["xetex"]={
  "XeTeXversion",
 },
}
